@@ -81,7 +81,7 @@ def json_events(fd):
     :param fd: file-like object to read from
     :return: an event generator
     """
-    return ijson_parse(ijson_basic_parse(fd))
+    return ijson_parse(ijson_basic_parse(fd, use_float=True))
 
 
 def json_items(events, prefix):
